==> ejc-proequipmentcorp-impl-3.0.0-20221017.101726-8-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentAcceptanceSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁设备验收明细
 *
 * @author generator
 *
 */
@TableName("ejc_proequipmentcorp_rent_acceptance_sub")
public class RentAcceptanceSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="specs")
    private String specs; // 规格型号
    @TableField(value="rent_mode")
    private String rentMode; // 租凭方式
    @TableField(value="equipment_appearance_code")
    private String equipmentAppearanceCode; // 设备出场编号
    @TableField(value="acceptance_result")
    private Integer acceptanceResult; // 验收结果:1-合格,2-不合格
    @TableField(value="acceptance_result_name")
    private String acceptanceResultName; // 验收结果
    @TableField(value="start_date")
    private Date startDate; // 启动时间
    @TableField(value="appearance_date")
    private Date appearanceDate; // 出厂日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="category_id")
    private Long categoryId; // 设备分类id
    @TableField(value="category_name")
    private String categoryName; // 设备分类
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编号
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="num")
    private Integer num; // 数量
    @TableField(value="rent_type_id")
    private Integer rentTypeId; // 租赁方式id:1--日租,2--月租,3--工程量
    @TableField(value="rent_type_name")
    private String rentTypeName; // 租赁方式名称
    @TableField(value="price")
    private BigDecimal price; // 租赁金额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 无税租赁金额
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="plan_into_date")
    private Date planIntoDate; // 计划进场日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="production_manufactor")
    private String productionManufactor; // 生成厂家
    @TableField(value="unit_name")
    private String unitName;
    @TableField(value="factory_code")
    private String factoryCode;
    @TableField(value="meter_rent_date")
    private Date meterRentDate;//计租日期
    @TableField(value="quantities_num")
    private Integer quantitiesNum;//工程数量
    @TableField(value="source_id")
    private Long sourceId;//工程数量
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private Long orderDetailId; // 订单明细主键ID
    @TableField(value="unit_id")
    private Long unitId; //

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }

    public Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    public void setDeliveryDetailId(Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Long getOrderDetailId() {
        return orderDetailId;
    }

    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getSpecs() {
        return specs;
    }

    public void setSpecs(String specs) {
        this.specs = specs;
    }
    public String getRentMode() {
        return rentMode;
    }

    public void setRentMode(String rentMode) {
        this.rentMode = rentMode;
    }
    public String getEquipmentAppearanceCode() {
        return equipmentAppearanceCode;
    }

    public void setEquipmentAppearanceCode(String equipmentAppearanceCode) {
        this.equipmentAppearanceCode = equipmentAppearanceCode;
    }
    public Integer getAcceptanceResult() {
        return acceptanceResult;
    }

    public void setAcceptanceResult(Integer acceptanceResult) {
        this.acceptanceResult = acceptanceResult;
    }
    public String getAcceptanceResultName() {
        return acceptanceResultName;
    }

    public void setAcceptanceResultName(String acceptanceResultName) {
        this.acceptanceResultName = acceptanceResultName;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getAppearanceDate() {
        return appearanceDate;
    }

    public void setAppearanceDate(Date appearanceDate) {
        this.appearanceDate = appearanceDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public Integer getRentTypeId() {
        return rentTypeId;
    }

    public void setRentTypeId(Integer rentTypeId) {
        this.rentTypeId = rentTypeId;
    }
    public String getRentTypeName() {
        return rentTypeName;
    }

    public void setRentTypeName(String rentTypeName) {
        this.rentTypeName = rentTypeName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Date getPlanIntoDate() {
        return planIntoDate;
    }

    public void setPlanIntoDate(Date planIntoDate) {
        this.planIntoDate = planIntoDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public String getFactoryCode() {
        return factoryCode;
    }

    public void setFactoryCode(String factoryCode) {
        this.factoryCode = factoryCode;
    }

    public Date getMeterRentDate() {
        return meterRentDate;
    }

    public void setMeterRentDate(Date meterRentDate) {
        this.meterRentDate = meterRentDate;
    }

    public Integer getQuantitiesNum() {
        return quantitiesNum;
    }

    public void setQuantitiesNum(Integer quantitiesNum) {
        this.quantitiesNum = quantitiesNum;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorprent/rent/bean/RentAcceptanceSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.rent.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租赁设备验收明细
 *
 * @author generator
 *
 */
@TableName("ejc_proequipmentcorp_rent_acceptance_sub")
public class RentAcceptanceSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 费用项目名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="specs")
    private String specs; // 规格型号
    @TableField(value="rent_mode")
    private String rentMode; // 租凭方式
    @TableField(value="equipment_appearance_code")
    private String equipmentAppearanceCode; // 设备出场编号
    @TableField(value="acceptance_result")
    private Integer acceptanceResult; // 验收结果:1-合格,2-不合格
    @TableField(value="acceptance_result_name")
    private String acceptanceResultName; // 验收结果
    @TableField(value="start_date")
    private Date startDate; // 启动时间
    @TableField(value="appearance_date")
    private Date appearanceDate; // 出厂日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="category_id")
    private Long categoryId; // 设备分类id
    @TableField(value="category_name")
    private String categoryName; // 设备分类
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编号
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="num")
    private Integer num; // 数量
    @TableField(value="rent_type_id")
    private Integer rentTypeId; // 租赁方式id:1--日租,2--月租,3--工程量
    @TableField(value="rent_type_name")
    private String rentTypeName; // 租赁方式名称
    @TableField(value="price")
    private BigDecimal price; // 租赁金额
    @TableField(value="not_tax_price")
    private BigDecimal notTaxPrice; // 无税租赁金额
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="plan_into_date")
    private Date planIntoDate; // 计划进场日期
    @TableField(value="plan_out_date")
    private Date planOutDate; // 计划出场日期
    @TableField(value="production_manufactor")
    private String productionManufactor; // 生成厂家
    @TableField(value="unit_name")
    private String unitName;
    @TableField(value="factory_code")
    private String factoryCode;
    @TableField(value="meter_rent_date")
    private Date meterRentDate;//计租日期
    @TableField(value="quantities_num")
    private Integer quantitiesNum;//工程数量
    @TableField(value="source_id")
    private Long sourceId;//工程数量
    @TableField(value="delivery_id")
    private Long deliveryId; // 发货主键ID
    @TableField(value="delivery_detail_id")
    private Long deliveryDetailId; // 发货明细主键ID
    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="order_detail_id")
    private Long orderDetailId; // 订单明细主键ID
    @TableField(value="unit_id")
    private Long unitId; //
    @TableField(value="check_before_id")
    private Long checkBeforeId; //进场前验收id
    @TableField(value="check_before_name")
    private String checkBeforeName; //进场前验收name
    @TableField(value="check_after_flag")
    private Integer checkAfterFlag; //是否安装验收 1-是 0-否

    public Integer getCheckAfterFlag() {
        return checkAfterFlag;
    }

    public void setCheckAfterFlag(Integer checkAfterFlag) {
        this.checkAfterFlag = checkAfterFlag;
    }

    public Long getCheckBeforeId() {
        return checkBeforeId;
    }

    public void setCheckBeforeId(Long checkBeforeId) {
        this.checkBeforeId = checkBeforeId;
    }

    public String getCheckBeforeName() {
        return checkBeforeName;
    }

    public void setCheckBeforeName(String checkBeforeName) {
        this.checkBeforeName = checkBeforeName;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public Long getDeliveryId() {
        return deliveryId;
    }

    public void setDeliveryId(Long deliveryId) {
        this.deliveryId = deliveryId;
    }

    public Long getDeliveryDetailId() {
        return deliveryDetailId;
    }

    public void setDeliveryDetailId(Long deliveryDetailId) {
        this.deliveryDetailId = deliveryDetailId;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }

    public Long getOrderDetailId() {
        return orderDetailId;
    }

    public void setOrderDetailId(Long orderDetailId) {
        this.orderDetailId = orderDetailId;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getSpecs() {
        return specs;
    }

    public void setSpecs(String specs) {
        this.specs = specs;
    }
    public String getRentMode() {
        return rentMode;
    }

    public void setRentMode(String rentMode) {
        this.rentMode = rentMode;
    }
    public String getEquipmentAppearanceCode() {
        return equipmentAppearanceCode;
    }

    public void setEquipmentAppearanceCode(String equipmentAppearanceCode) {
        this.equipmentAppearanceCode = equipmentAppearanceCode;
    }
    public Integer getAcceptanceResult() {
        return acceptanceResult;
    }

    public void setAcceptanceResult(Integer acceptanceResult) {
        this.acceptanceResult = acceptanceResult;
    }
    public String getAcceptanceResultName() {
        return acceptanceResultName;
    }

    public void setAcceptanceResultName(String acceptanceResultName) {
        this.acceptanceResultName = acceptanceResultName;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getAppearanceDate() {
        return appearanceDate;
    }

    public void setAppearanceDate(Date appearanceDate) {
        this.appearanceDate = appearanceDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public Integer getRentTypeId() {
        return rentTypeId;
    }

    public void setRentTypeId(Integer rentTypeId) {
        this.rentTypeId = rentTypeId;
    }
    public String getRentTypeName() {
        return rentTypeName;
    }

    public void setRentTypeName(String rentTypeName) {
        this.rentTypeName = rentTypeName;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getNotTaxPrice() {
        return notTaxPrice;
    }

    public void setNotTaxPrice(BigDecimal notTaxPrice) {
        this.notTaxPrice = notTaxPrice;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Date getPlanIntoDate() {
        return planIntoDate;
    }

    public void setPlanIntoDate(Date planIntoDate) {
        this.planIntoDate = planIntoDate;
    }
    public Date getPlanOutDate() {
        return planOutDate;
    }

    public void setPlanOutDate(Date planOutDate) {
        this.planOutDate = planOutDate;
    }
    public String getProductionManufactor() {
        return productionManufactor;
    }

    public void setProductionManufactor(String productionManufactor) {
        this.productionManufactor = productionManufactor;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public String getFactoryCode() {
        return factoryCode;
    }

    public void setFactoryCode(String factoryCode) {
        this.factoryCode = factoryCode;
    }

    public Date getMeterRentDate() {
        return meterRentDate;
    }

    public void setMeterRentDate(Date meterRentDate) {
        this.meterRentDate = meterRentDate;
    }

    public Integer getQuantitiesNum() {
        return quantitiesNum;
    }

    public void setQuantitiesNum(Integer quantitiesNum) {
        this.quantitiesNum = quantitiesNum;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
}
